@@ -15,10 +15,13 @@ class ProgBar(Prog):
     Keyword Arguments:
         iterations (int): number of iterations of the computation
         track_time (bool): prints elapsed time when loop has finished
+        width (int): sets the progress bar width in characters.
         stream: takes 1 for stdout, 2 for stderr, or given stream object
+        title (str): A title for the progress bar
+
     """
-    def __init__(self, iterations, track_time=True, width=30, stream=2):
-        Prog.__init__(self, iterations, track_time, stream)
+    def __init__(self, iterations, track_time=True, width=30, stream=2, title=''):
+        Prog.__init__(self, iterations, track_time, stream, title)
         self.bar_width = width
         self._adjust_width()
         self.last_progress = 0
